( cd usr/man/preformat/cat1 ; rm -rf xfilemanager.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf /cdrom/usr/man/preformat/cat1/xfilemanager.1.gz xfilemanager.1.gz )
( cd usr/X11R6/bin ; rm -rf xfilemanager )
( cd usr/X11R6/bin ; ln -sf /cdrom/usr/X11R6/bin/xfilemanager xfilemanager )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf animation.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/animation.xbm animation.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf binary.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/binary.xbm binary.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf compress.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/compress.xbm compress.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf compressor.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/compressor.xbm compressor.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf decompressor.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/decompressor.xbm decompressor.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf dev_printer.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/dev_printer.xbm dev_printer.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf file_bin.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/file_bin.xbm file_bin.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf file_compressed.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/file_compressed.xbm file_compressed.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf file_core.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/file_core.xbm file_core.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf file_ctar.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/file_ctar.xbm file_ctar.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf file_dvi.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/file_dvi.xbm file_dvi.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf file_graph.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/file_graph.xbm file_graph.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf file_movie.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/file_movie.xbm file_movie.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf file_pix.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/file_pix.xbm file_pix.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf file_source.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/file_source.xbm file_source.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf file_tar.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/file_tar.xbm file_tar.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf file_text.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/file_text.xbm file_text.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf ftp.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/ftp.xbm ftp.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf news.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/news.xbm news.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf picture.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/picture.xbm picture.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf printer.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/printer.xbm printer.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf source.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/source.xbm source.xbm )
( cd usr/X11R6/include/X11/bitmaps ; rm -rf texteditor.xbm )
( cd usr/X11R6/include/X11/bitmaps ; ln -sf /cdrom/usr/X11R6/include/X11/bitmaps/texteditor.xbm texteditor.xbm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf dev_cdrom.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/dev_cdrom.xpm dev_cdrom.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf dev_hfloppy.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/dev_hfloppy.xpm dev_hfloppy.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf dev_lfloppy.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/dev_lfloppy.xpm dev_lfloppy.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf dir_closed.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/dir_closed.xpm dir_closed.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf dir_locked.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/dir_locked.xpm dir_locked.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf dir_opened.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/dir_opened.xpm dir_opened.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf dragon.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/dragon.xpm dragon.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf file_bin.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/file_bin.xpm file_bin.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf file_compressed.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/file_compressed.xpm file_compressed.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf file_core.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/file_core.xpm file_core.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf file_ctar.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/file_ctar.xpm file_ctar.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf file_dlink.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/file_dlink.xpm file_dlink.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf file_dvi.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/file_dvi.xpm file_dvi.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf file_exec.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/file_exec.xpm file_exec.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf file_graph.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/file_graph.xpm file_graph.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf file_link.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/file_link.xpm file_link.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf file_lock.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/file_lock.xpm file_lock.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf file_movie.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/file_movie.xpm file_movie.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf file_pix.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/file_pix.xpm file_pix.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf file_plain.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/file_plain.xpm file_plain.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf file_root.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/file_root.xpm file_root.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf file_source.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/file_source.xpm file_source.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf file_tar.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/file_tar.xpm file_tar.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf file_text.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/file_text.xpm file_text.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf floppy3.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/floppy3.xpm floppy3.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf mail.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/mail.xpm mail.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf tank.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/tank.xpm tank.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf xconq.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/xconq.xpm xconq.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf xdesigner.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/xdesigner.xpm xdesigner.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf xedit.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/xedit.xpm xedit.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf xlogo.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/xlogo.xpm xlogo.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf xmore.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/xmore.xpm xmore.xpm )
( cd usr/X11R6/include/X11/pixmaps ; rm -rf xterm.xpm )
( cd usr/X11R6/include/X11/pixmaps ; ln -sf /cdrom/usr/X11R6/include/X11/pixmaps/xterm.xpm xterm.xpm )
